@@ -8,7 +8,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION          = '0.16';
+our $VERSION          = '0.17';
 our @CANNED_RESPONSES = ();
 
 use LWP::UserAgent;
@@ -62,6 +62,8 @@ sub search {
         $req = Net::Amazon::Request::ASIN->new(%params);
     } elsif(exists $params{artist}) {
         $req = Net::Amazon::Request::Artist->new(%params);
+    } elsif(exists $params{blended}) {
+        $req = Net::Amazon::Request::Blended->new(%params);
     } elsif(exists $params{wishlist}) {
         $req = Net::Amazon::Request::Wishlist->new(
                                    id => $params{wishlist}, %params);
@@ -522,6 +524,13 @@ Can return many results.
 Music search by UPC (product barcode), mandatory parameter C<upc>.
 C<mode> has to be set to C<music>. Returns at most one result.
 
+=item Net::Amazon::Request::Blended
+
+'Blended' search on a keyword, resulting in matches across the board.
+No 'mode' parameter is allowed. According to Amazon's developer's kit, 
+this will result in up to three matches per category and can yield
+a total of 45 matches.
+
 =back
 
 Check the respective man pages for details on these request objects.
@@ -911,6 +920,7 @@ Contributors (thanks y'all!):
     Martha Greenberg <marthag@mit.edu>
     Martin Streicher <martin.streicher@apress.com>
     Mike Evron <evronm@dtcinc.net>
+    Robert Graff, <rgraff@workingdemo.com>
     Tony Bowden <tony@kasei.com>
 
 =head1 COPYRIGHT AND LICENSE
